@@ -99,3 +99,19 @@ def get_object_by_id(model, object_id):
         result = object_id
 
     return result
+
+
+def compare(a, b):
+    """
+    Сравнение значений.
+    Сделана для совместимости с Python 3, где нельзя сравнивать с None.
+    А тут можно :)
+    """
+    if a is None and b is None:
+        return 0
+    elif a is None:
+        return -1
+    elif b is None:
+        return 1
+    else:
+        return (a > b) - (a < b)
