@@ -22,30 +22,43 @@ class ProjectConfig:
         if filenames:
             self.parser.read(filenames)
         self.defauls = defaults
-        
+
     def read(self, filenames):
         """
         Загружает конфигурацию из файла(ов) filenames
         """
         self.parser = configparser.ConfigParser()
         self.parser.read(filenames)
-    
+
     def set_defaults(self, defaults):
         """
         Устанавливает параметры проекта по умолчанию
         """
         self.defauls = defaults
-        
+
+    def update_defaults(self, update_values):
+        """
+        Обновляет параметры по умолчанию
+
+        Возвращает итоговый словарь с умолчаниями
+
+        :param dict update_values: словарь с обновляемыми значениями
+        :return dict: итоговые параметры по умолчанию
+        """
+        self.defauls.update(update_values)
+
+        return self.defauls
+
     def items(self, section):
         """
         Возвращает список кортежей (key, value) из указанной секции.
         В случае, если такой секции нет, то возвращается пустой список.
         """
         return self.parser.items(section) if self.parser.has_section(section) else []
-    
+
     def get(self, section, option):
         """
-        Безопастно возвращает значение конфигурационного параметра option
+        Безопасно возвращает значение конфигурационного параметра option
         из раздела section
         """
         try:
@@ -57,7 +70,19 @@ class ProjectConfig:
             if (section,option) in self.defauls:
                 return self.defauls[(section,option)]
         return ''
-    
+
+    def set(self, section, option, value):
+        """
+        Устанавливает значение конфигурационного параметра.
+
+        :param str section: раздел
+        :param str option: параметр
+        :param str value: устанавливаемое значение
+        """
+        if not self.parser.has_section(section):
+            self.parser.add_section(section)
+        self.parser.set(section, option, value)
+
     def get_bool(self, section, option):
         """
         Безопастно возвращает булево из конфига
@@ -68,7 +93,6 @@ class ProjectConfig:
 
         return bool(value)
 
-        
     def get_int(self, section, option):
         """
         Безопасно возвращает целое число из конфига
@@ -80,7 +104,7 @@ class ProjectConfig:
             except:
                 value = 0
         return value
-        
+
     def get_uint(self, section, option):
         """
         Безопасно возвращает положительное целое число из конфига
@@ -89,4 +113,3 @@ class ProjectConfig:
         if value < 0:
             value = 0
         return value
-    
\ No newline at end of file
