@@ -15,6 +15,8 @@ from django.conf import settings
 from django.db.models import Q, Count, Avg, Max, Min, Sum
 import six
 from six.moves import range
+from m3_legacy import compare
+
 
 try:
     import xlwt
@@ -422,8 +424,8 @@ class GroupingRecordProvider(object):
         for column in columns:
             if not column.get("hidden"):
                 ws.write(1, index, column.get('header'), header_style)
-                ws.col(index).width = 1.0 * column.get(
-                    "width") * page_width / total_width
+                ws.col(index).width = column.get(
+                    "width") * page_width // total_width
                 columns_title[column["data_index"]] = column.get('header')
                 columns_cash.append(column["data_index"])
                 index += 1
@@ -932,7 +934,7 @@ class GroupingRecordDataProvider(GroupingRecordProvider):
             for rec in self.get_data():
                 # будем считать агрегаты
                 self.update_aggregates(aggregates, aggr_rec, rec)
-                count += 1
+                count += self.get_record_aggregate_value(rec)
             item = self.create_record()
             self.setattr(item, 'id', None)
             self.setattr(item, 'indent', None)
@@ -942,9 +944,11 @@ class GroupingRecordDataProvider(GroupingRecordProvider):
                 for agg, aggv in six.iteritems(aggregates):
                     # для средних - посчитаем среднее
                     if aggv == 'avg':
+                        count = self.getattr(item, 'count')
                         self.setattr(
                             item, agg,
-                            aggr_rec[agg] / self.getattr(item, 'count')
+                            0 if count == 0 else
+                            round(aggr_rec[agg] * 1.0 / count, 2)
                         )
                     elif callable(aggv):
                         self.setattr(
@@ -1013,11 +1017,13 @@ class GroupingRecordDataProvider(GroupingRecordProvider):
                     self.setattr(item, 'count', level[i])
                     for agg, aggv in six.iteritems(aggregates):
                         # для средних - посчитаем среднее
-                        if agg == 'avg':
+                        if aggv == 'avg':
+                            count = self.getattr(
+                                item, self.get_record_aggregate())
                             self.setattr(
                                 item, agg,
-                                aggregate_values[i][agg] / (
-                                    self.getattr(item, 'count'))
+                                0 if count == 0 else
+                                round(aggregate_values[i][agg] * 1.0 / count, 2)
                             )
                         elif callable(aggv):
                             self.setattr(
@@ -1285,8 +1291,6 @@ class GroupingRecordDataProvider(GroupingRecordProvider):
             ) for col in columns
         ]
 
-        compare = lambda a, b: (a > b) - (a < b)
-
         def comparer(left, right):
             for attr, mult in comparers:
                 result = compare(
@@ -1298,3 +1302,19 @@ class GroupingRecordDataProvider(GroupingRecordProvider):
             else:
                 return 0
         return sorted(items, key=cmp_to_key(comparer))
+
+    def get_record_aggregate_value(self, rec):
+        """Используется при расчете количества записей
+
+        По умолчанию считаются все записи,
+        при переопределении в наследнике можно использовать
+        self.getattr(rec, 'count')
+        """
+        return 1
+
+    def get_record_aggregate(self):
+        """Используется при расчете среднего значения
+
+        По умолчанию делим сумму по записям на значение агрегата count
+        """
+        return 'count'
